@@ -145,6 +145,9 @@ def nlp_engine_main(abstracts_log_name, status_logger_name):
 	nlp_engine_main_start_status_key = "Initiating the NLP Engine"
 	status_logger(status_logger_name, nlp_engine_main_start_status_key)
 
+	'''Declaring the number of topics to be generated by the LDA model'''
+	num_topics = 10
+
 	'''Extracts the data from the .txt file and puts them into a Pandas dataframe buckets'''
 	textual_dataframe = data_reader(abstracts_log_name, status_logger_name)
 	'''Rids the symbols and special characters from the textual_data'''
@@ -166,7 +169,7 @@ def nlp_engine_main(abstracts_log_name, status_logger_name):
 	lda_model_generation_start_status_key = "Generating the LDA model using default parameter set"
 	status_logger(status_logger_name, lda_model_generation_start_status_key)
 
-	lda_model = gensim.models.ldamodel.LdaModel(corpus = corpus, id2word = id2word, num_topics = 10, random_state = 100, update_every = 1, chunksize = 100, passes = 10, alpha = 'auto', per_word_topics = True)
+	lda_model = gensim.models.ldamodel.LdaModel(corpus = corpus, id2word = id2word, num_topics = num_topics, random_state = 100, update_every = 1, chunksize = 100, passes = 10, alpha = 'auto', per_word_topics = True)
 
 	lda_model_generation_end_status_key = "Generated the LDA model using default parameter set"
 	status_logger(status_logger_name, lda_model_generation_end_status_key)
@@ -180,6 +183,6 @@ def nlp_engine_main(abstracts_log_name, status_logger_name):
 	status_logger(status_logger_name, nlp_engine_main_end_status_key)
 
 	'''Importing the visualizer_main function to view the LDA Model built by the NLP_engine_main() function'''
-	visualizer_main(lda_model, corpus, id2word, abstracts_log_name, status_logger_name)
+	visualizer_main(lda_model, corpus, id2word, textual_data_lemmatized, num_topics, abstracts_log_name, status_logger_name)
 
 	return 0
\ No newline at end of file
